"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[9736],{58342:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(31532)),u=l(a(98829)),f=l(a(61023)),s=l(a(14095)),d=l(a(88369)),n={code:"ta",formatDistance:o.default,formatLong:u.default,formatRelative:f.default,localize:s.default,match:d.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-ta-index-js.js.map