"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[6367],{61125:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(48959)),u=l(a(21994)),f=l(a(78384)),n=l(a(16656)),s=l(a(34872)),d={code:"bn",formatDistance:o.default,formatLong:u.default,formatRelative:f.default,localize:n.default,match:s.default,options:{weekStartsOn:0,firstWeekContainsDate:1}};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-bn-index-js.js.map