"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[4139],{52839:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var f=l(a(46367)),o=l(a(4112)),u=l(a(51352)),s=l(a(45636)),d=l(a(39790)),n={code:"fr-CH",formatDistance:f.default,formatLong:s.default,formatRelative:d.default,localize:o.default,match:u.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-fr-CH-index-js.js.map