"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[8637],{81597:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(26376)),u=l(a(12568)),f=l(a(85024)),n=l(a(711)),s=l(a(49218)),d={code:"en-CA",formatDistance:n.default,formatLong:s.default,formatRelative:o.default,localize:u.default,match:f.default,options:{weekStartsOn:0,firstWeekContainsDate:1}};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-en-CA-index-js.js.map