"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[4853],{34055:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(40553)),u=l(a(42628)),f=l(a(45518)),s=l(a(92910)),d=l(a(72778)),n={code:"lv",formatDistance:o.default,formatLong:u.default,formatRelative:f.default,localize:s.default,match:d.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-lv-index-js.js.map