"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[6499],{17139:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var u=l(a(78357)),o=l(a(55936)),f=l(a(36114)),s=l(a(41898)),d=l(a(97390)),n={code:"uz-Cyrl",formatDistance:u.default,formatLong:o.default,formatRelative:f.default,localize:s.default,match:d.default,options:{weekStartsOn:1,firstWeekContainsDate:1}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-uz-Cyrl-index-js.js.map