"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[7800],{62694:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o=l(a(14540)),u=l(a(11034)),d=l(a(98399)),f=l(a(62255)),s=l(a(6609)),n={code:"gd",formatDistance:o.default,formatLong:u.default,formatRelative:d.default,localize:f.default,match:s.default,options:{weekStartsOn:0,firstWeekContainsDate:1}};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-gd-index-js.js.map