"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[23],{39803:(n,e,t)=>{t.r(e),t.d(e,{IconSvgPaths16:()=>c,IconSvgPaths20:()=>o,getIconPaths:()=>r,iconNameToPathsRecordKey:()=>u});var s=t(43261),c=t(96491),o=t(68748),a=t(6134);function r(n,e){var t=(0,s.fL)(n);return e===a.l.STANDARD?c[t]:o[t]}function u(n){return(0,s.fL)(n)}}}]);
//# sourceMappingURL=async-blueprint-icons-all-paths.js.map