"use strict";(self.webpackChunkdash_blueprint_components=self.webpackChunkdash_blueprint_components||[]).push([[7955],{46553:(e,t,a)=>{var l=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n=l(a(30611)),o=l(a(97054)),u=l(a(7724)),f=l(a(64020)),s=l(a(99060)),d={code:"nn",formatDistance:n.default,formatLong:o.default,formatRelative:u.default,localize:f.default,match:s.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=async-date-fns-locale-nn-index-js.js.map