.docs-nav-section {
    font-size: small;
    font-weight: 700;
    margin-bottom: 10px;
    margin-top: 20px;
    text-transform: uppercase
}

.docs-nav-section+.docs-nav-menu {
    margin-left: 0
}

.docs-nav-package.docs-nav-expanded,
.docs-nav-package:hover{
    color: #215db0;
}

.docs-nav-expanded+.docs-nav-menu {
    display: block
}

.docs-nav-menu .bp5-menu-item.bp5-active,
.docs-nav-menu .bp5-menu-item.docs-nav-expanded,
.docs-nav-menu .bp5-menu-item:hover {
    background-color: transparent !important;
    font-weight: 600
}

.docs-nav-package-icon {
    border-radius: 6px;
    margin-right: 10px
}

.docs-nav-package {
    align-items: center;
    display: flex;
    flex-direction: row
}

.docs-nav-package.docs-nav-expanded,
.docs-nav-package:hover{
    color: #215db0;
}

.docs-nav-package>* {
    flex-grow: 0;
    flex-shrink: 0
}

.docs-nav-package>.bp5-fill {
    flex-grow: 1;
    flex-shrink: 1
}

.docs-nav-package .bp5-menu-item {
    background-color: transparent;
    flex: 1 1 auto;
    font-weight: 600;
    text-transform: uppercase;
}

.docs-nav-package+.docs-nav-menu {
    margin-bottom: 5px;
    margin-left: 34px
}

.docs-nav-package+.docs-nav-menu:empty {
    display: none
}

.depth-1>.docs-title {
    margin-top: 20px
}

.docs-nav-menu .bp5-menu-item.depth-1 {
    padding-left: 20px
}

.docs-nav-menu .bp5-menu-item.depth-2 {
    padding-left: 40px
}

.docs-nav-menu .bp5-menu-item.depth-3 {
    padding-left: 60px
}

.docs-nav-menu .bp5-menu-item.depth-4 {
    padding-left: 80px
}

.docs-nav-menu .bp5-menu-item.depth-5 {
    padding-left: 100px
}

.docs-nav-menu .bp5-menu-item {
    align-items: center;
    padding-left: 0;
    padding-right: 10px;
    white-space: normal
}

.docs-nav-menu .bp5-menu-item.bp5-active,
.docs-nav-menu .bp5-menu-item.docs-nav-expanded,
.docs-nav-menu .bp5-menu-item:hover {
    background-color: transparent !important;
    font-weight: 600
}

.docs-nav-menu .docs-nav-menu {
    display: none;
    margin-left: 20px
}

.docs-nav-expanded+.docs-nav-menu {
    display: block
}

.docs-nav-menu:empty+.docs-empty-state {
    display: block
}

